@@ -1,7 +1,7 @@
 #!/bin/bash
 
-set -eux
-set -o pipefail
+set -euxo pipefail
+
 export PYTHONUNBUFFERED=1
 SCRIPT_HOME="$(cd "$(dirname "$0")" && pwd)"
 BIFROST_HOME=$SCRIPT_HOME/..
@@ -65,6 +65,11 @@ source $SCRIPT_HOME/env-setup.sh
 
 # We're expected to test with SELinux enforcing
 if which setenforce &> /dev/null; then
+    SELINUX_STATUS=$(sudo getenforce)
+    if [ "$SELINUX_STATUS" == "Disabled" ]; then
+        echo "Selinux is Disabled, please enable it and restart the host"
+        exit 1
+    fi
     sudo setenforce Enforcing
 fi
 
